

## Installation

ControlFlow requires Python 3.9 or greater, as well as Prefect 3.0.

Install ControlFlow with your preferred package manager:
<CodeGroup>
    
```bash pip
pip install controlflow 
```

```bash uv
uv pip install controlflow 
```
</CodeGroup>

ControlFlow is under active development, so we recommend frequently updating to the latest version to access new features and bug fixes. To upgrade, pass the `-U` flag when installing.


### Install for development

To install ControlFlow for development, clone the repository and create an editable install with development dependencies:

```bash
git clone https://github.com/PrefectHQ/ControlFlow.git
cd controlflow
pip install -e ".[dev]"
```

## Next steps

Check out the [tutorial](/tutorial) guide for a step-by-step walkthrough of creating your first ControlFlow workflow.

